@@ -351,7 +351,7 @@ def ncToPiv2D(miss, outdir = None,
 		outdir = os.path.dirname(miss)
 	
 	#Translate data from netcdf into Sv, TS, etc.
-	Sv,env,aop = zp.get_Sv(miss, beam=b, ping=p,
+	Sv,env,aop = get_Sv(miss, beam=b, ping=p,
 			 fix_c=fix_c,fix_alpha=fix_alpha,fix_sl=fix_sl,pitchfix=pitchfix)
 	
 	if f == 0:
